@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use base qw/DBIx::Class::Storage::DBI::UniqueIdentifier/;
 use mro 'c3';
+use List::Util 'first';
 use Try::Tiny;
 use namespace::clean;
 
@@ -48,8 +49,8 @@ sub _prefetch_autovalues {
 
   my $values = $self->next::method(@_);
 
-  my ($identity_col) =
-    grep { $colinfo->{$_}{is_auto_increment} } keys %$colinfo;
+  my $identity_col =
+    first { $colinfo->{$_}{is_auto_increment} } keys %$colinfo;
 
 # user might have an identity PK without is_auto_increment
 #
@@ -138,15 +139,14 @@ sub select_single {
 
 sub build_datetime_parser {
   my $self = shift;
-  my $type = "DateTime::Format::Strptime";
   try {
-    eval "require ${type}"
+    require DateTime::Format::Strptime;
   }
   catch {
-    $self->throw_exception("Couldn't load ${type}: $_");
+    $self->throw_exception("Couldn't load DateTime::Format::Strptime: $_");
   };
 
-  return $type->new( pattern => '%Y-%m-%d %H:%M:%S.%6N' );
+  return DateTime::Format::Strptime->new( pattern => '%Y-%m-%d %H:%M:%S.%6N' );
 }
 
 =head2 connect_call_datetime_setup
